function EP = EarthParam(Depth)
% EP = EarthParam(Depth)
% EP is a structure containing Earth parameters corresponding to the array Depth.
%
% Written by Oliver Boyd
% V0.1 Released Nov. 16th 2007
%
% The program loads PREM data from Prem.txt and Thermodynamic data from ThermoParam.txt.  
% The format from prem.txt and ThermoParam.txt can be seen from the following lines.
% Prem.txt was acquired from prem.html which was aquired from
% http://geowww.gcn.ou.edu/~jahern/solid_earth/prem.html. It corresponds to PREM model
% for 1 s and is missing several layers in the deep earth. ThermoParam.txt was acquired
% from appendix F of Stacey's Physics of the Earth.
%
% Depth is in km
% velocities are in m/s
% density in kg/m3
% pressures and moduli in GPa
% acceleration due to gravity in m/s2
%

%a = 0.25;
a = 0.15;

load Prem.txt;

R1 = Prem(1:10:560);
PVel = Prem(2:10:560);
SVel = Prem(3:10:560);
D = Prem(4:10:560);
BulkMod = Prem(5:10:560);
ShearMod = Prem(6:10:560);
PoisRat = Prem(7:10:560);
P = Prem(8:10:560);
g = Prem(9:10:560);
Qmu = Prem(10:10:560);
SVelu = SVel./(1-.5*cot(a*pi/2)*(1./Qmu));

load ThermoParam.txt

R2 = ThermoParam(:,1);
T = ThermoParam(:,2);
Tm = ThermoParam(:,3);
DebT = ThermoParam(:,4);
gamma = ThermoParam(:,5);
Cp = ThermoParam(:,6);
alpha = ThermoParam(:,7);
kappa = ThermoParam(:,8);
eta = ThermoParam(:,9);
sigma = ThermoParam(:,10);

EP.Depth = Depth;
EP.PVel = interp1(6371-R1,PVel,Depth,'linear');
EP.SVel = interp1(6371-R1,SVel,Depth,'linear');
EP.SVelu = interp1(6371-R1,SVelu,Depth,'linear');
EP.Qmu = interp1(6371-R1,Qmu,Depth,'linear');
EP.Density = interp1(6371-R1,D,Depth,'linear');
EP.BulkMod = interp1(6371-R1,BulkMod,Depth,'linear');
EP.ShearMod = interp1(6371-R1,ShearMod,Depth,'linear');
EP.PoisRat = interp1(6371-R1,PoisRat,Depth,'linear');
EP.Pressure = interp1(6371-R1,P,Depth,'linear');
EP.g = interp1(6371-R1,g,Depth,'linear');

EP.Temperature= interp1(6371-R2,T,Depth,'linear');
EP.TemperatureC = EP.Temperature - 273.15;
EP.MeltTemp = interp1(6371-R2,Tm,Depth,'linear');
EP.DebyeTemp = interp1(6371-R2,DebT,Depth,'linear');
EP.gamma = interp1(6371-R2,gamma,Depth,'linear');
EP.SpecificHeat = interp1(6371-R2,Cp,Depth,'linear');
EP.ThermalExpansivity = interp1(6371-R2,alpha,Depth,'linear');
EP.Conductivity = interp1(6371-R2,kappa,Depth,'linear');
EP.eta = interp1(6371-R2,eta,Depth,'linear');
EP.sigma = interp1(6371-R2,sigma,Depth,'linear');

EP.R = 8.31447114; % J/(mol*K)

